.icons-on .contenttype-teaser {
    display: inline-block;
    line-height: 2em;
    padding-left: 20px !important; 
    background:url("++resource++collective-teaser-resources/teaser_icon.png") no-repeat scroll 0 0 transparent;
}